@@ -1,5 +1,5 @@
 void info(void);
 void statistics_menu(void);
 void heartbeat(void);
-void do_check_for_mail(dtime_t ts);
+void do_check_for_mail();
 void store_statistics(proginfo *cur, dtime_t now);
