@@ -34,9 +34,9 @@
 /* syslog receive */
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <netdb.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <netdb.h>
 #ifdef UTF8_SUPPORT
 #include <wchar.h>
 #include <wctype.h>
@@ -457,6 +457,9 @@ char find_highlight_matches(regmatch_t *matches, char use_regex, int offset)
 {
 	int match_offset;
 
+	if (!matches)
+		return 0;
+
 	for(match_offset=0; match_offset<MAX_N_RE_MATCHES; match_offset++)
 	{
 		char matching;
@@ -617,8 +620,14 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 
 #ifdef UTF8_SUPPORT
 		const char *dummy = &use_string[offset];
-		wchar_t wcur = 0;
-		mbsrtowcs(&wcur, &dummy, 1, NULL);
+
+		wchar_t wcur = '?';
+		static mbstate_t state;
+
+		if (mbsrtowcs(&wcur, &dummy, 1, &state) == -1) {
+			wcur = '?';
+			memset(&state, 0x00, sizeof(mbstate_t));
+		}
 #else
 		char wcur = use_string[offset];
 #endif
@@ -692,7 +701,9 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 
 		if (!is_control_or_extended_ascii)
 		{
-#ifdef UTF8_SUPPORT
+#if defined(UTF8_SUPPORT) && defined(NCURSES_WIDECHAR)
+// FIXME warning: implicit declaration of function ‘waddnwstr’ is invalid in C99  [-Wimplicit-function-declaration]
+// see /usr/include/ncurses.h
 			waddnwstr(win -> win, &wcur, 1);
 #else
 			wprintw(win -> win, "%c", wcur);
@@ -1342,7 +1353,6 @@ void update_statusline(NEWWIN *status, int win_nr, proginfo *cur)
 {
 	if (mode_statusline > 0 && status != NULL && cur != NULL)
 	{
-		int dx;
 		myattr_t attrs = statusline_attrs;
 		int statusline_len = 0;
 		off64_t	fsize = (off64_t)-1;
@@ -3092,6 +3102,8 @@ int check_paths(void)
 			} /* check all matched files */
 
 			cdg[loop].last_check = now;
+
+			globfree(&files);
 		} /* time for a check? */
 	} /* check all search patterns  */
 
@@ -3208,8 +3220,6 @@ char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_o
 
 	if (strchr(&data_in[new_data_offset], '\n'))
 	{
-		char emitted = 0;
-
 		if (cur -> cont) /* reconnect lines with '\' */
 		{
 			char *contsearch = pnt;
@@ -3220,6 +3230,16 @@ char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_o
 			}
 		}
 
+		if (cur -> restart.is_restarted && cur -> restart.restart_clear)
+		{
+delete_be_in_buffer(&lb[win_nr]);
+			cur -> restart.is_restarted = 0;
+			werase(pi[win_nr].data -> win);
+		}
+
+		update_panels();
+
+
 		/* display lines */
 		for(;*pnt;)
 		{
@@ -3269,20 +3289,6 @@ char process_input_data(int win_nr, proginfo *cur, char *data_in, int new_data_o
 
 				statusline_update_needed |= emit_to_buffer_and_term(win_nr, cur, pnt);
 			}
-
-			if (!emitted)
-			{
-				emitted = 1;
-
-				if (cur -> restart.is_restarted && cur -> restart.restart_clear)
-				{
-					cur -> restart.is_restarted = 0;
-					werase(pi[win_nr].data -> win);
-				}
-
-				update_panels();
-			}
-
 			pnt = end + 1;
 		}
 	}
