@@ -175,20 +175,22 @@ int mykillpg(pid_t pid, int sigtype)
 /** stop_process
  * - in:      int pid  pid of process
  * - returns: nothing
- * this function sends a TERM-signal to the given process, sleeps for 1009 microseconds
+ * this function sends a TERM-signal to the given process, sleeps for 1000 microseconds
  * and then sends a KILL-signal to the given process if it still exists. the TERM signal
- * is send so the process gets the possibility to gracefully exit. if it doesn't do that
- * in 100 microseconds, it is terminated
+ * is sent so the process gets the possibility to gracefully exit. if it doesn't do that
+ * in 1000 microseconds, it is terminated
  */
 void stop_process(pid_t pid)
 {
 	assert(pid > 1);
 
+#ifndef __APPLE__
 	if (mykillpg(pid, SIGTERM) == -1)
 	{
 		if (errno != ESRCH)
 			error_exit(TRUE, FALSE, "Problem stopping child process with PID %d (SIGTERM).\n", pid);
 	}
+#endif
 
 	usleep(1000);
 
@@ -201,12 +203,26 @@ void stop_process(pid_t pid)
 		/* ...and then really terminate the process */
 		if (mykillpg(pid, SIGKILL) == -1)
 		{
+#ifdef __APPLE__
+			/* don't exit if the error is EPERM: macOS doesn't allow
+			   you to kill a process that has been already killed
+			   (i.e. zombies), which is what we did with the second
+			   mykillpg above. */
+			if (errno != ESRCH && errno != EPERM)
+#else
 			if (errno != ESRCH)
+#endif
 				error_exit(TRUE, FALSE, "Problem stopping child process with PID %d (SIGKILL).\n", pid);
 		}
 	}
+#ifdef __APPLE__
+	else if (errno != ESRCH && errno != EPERM)
+#else
 	else if (errno != ESRCH)
+#endif
+	{
 		error_exit(TRUE, FALSE, "Problem stopping child process with PID %d (SIGTERM).\n", pid);
+	}
 
 	/* wait for the last remainder of the died process to go away,
 	 * otherwhise we'll find zombies on our way
@@ -216,6 +232,29 @@ void stop_process(pid_t pid)
 		if (errno != ECHILD)
 			error_exit(TRUE, FALSE, "waitpid() failed\n");
 	}
+
+#ifdef __APPLE__
+	/* since we ignored the case of a EPERM error above,
+	   check if the process got stopped regardless or
+	   if we actually failed to stop it */
+	BOOL process_gone = FALSE;
+	for (int i = 0; i < 10; i++)
+	{
+		if (i != 0)
+			usleep(1000);
+		if (mykillpg(pid, 0) == -1)
+		{
+				if (errno == ESRCH)
+				{
+						process_gone = TRUE;
+						break;
+				}
+		}
+	}
+
+	if (!process_gone)
+		error_exit(TRUE, FALSE, "Could not confirm that child process with PID %d has been stopped.\n", pid);
+#endif
 }
 
 /** delete_array
@@ -434,9 +473,8 @@ char * shorten_filename(char *in, int max_len)
 double get_ts(void)
 {
 	struct timeval ts;
-	struct timezone tz;
 
-	if (gettimeofday(&ts, &tz) == -1)
+	if (gettimeofday(&ts, NULL) == -1)
 		error_exit(TRUE, FALSE, "gettimeofday() failed");
 
 	return (((double)ts.tv_sec) + ((double)ts.tv_usec)/1000000.0);
